Changeset: 1fc9b5938ff9 for MonetDB
URL: http://dev.monetdb.org/hg/MonetDB?cmd=changeset;node=1fc9b5938ff9
Modified Files:
        monetdb5/modules/mal/replication.mx
        sql/backends/monet5/datacell/actuator.c
        sql/backends/monet5/datacell/emitter.c
        sql/backends/monet5/datacell/receptor.c
Branch: Dec2011
Log Message:

English: the verb is "to send", the past and perfect tenses are "sent".


diffs (75 lines):

diff --git a/monetdb5/modules/mal/replication.mx 
b/monetdb5/modules/mal/replication.mx
--- a/monetdb5/modules/mal/replication.mx
+++ b/monetdb5/modules/mal/replication.mx
@@ -942,7 +942,7 @@ The master has to assume that the slave 
 */
 static struct MASTERrecord {
        str uri;
-       oid tag;        /* next one to sent */
+       oid tag;        /* next one to send */
        Mapi m;
        time_t last_connect;
        time_t last_disconnect;
@@ -964,7 +964,7 @@ MASTERsend(void *arg)
        /* find the last replication log file */
        master = GDKgetenv_istrue("replication_master") &&
                         GDKgetenv("replication_slave") == NULL;
-       /* If the slave starts from scratch, it will sent the 0-tag.
+       /* If the slave starts from scratch, it will send the 0-tag.
         * This can simply be replaced by the lowest number known.  But,
         * then the slave should use the BATmax option instead of the
         * BATcount to determine the tag. */
@@ -1012,7 +1012,7 @@ MASTERsend(void *arg)
                        mal_set_lock(repLck, "replication");
                if (repFile)
                        mnstr_flush(repFile);
-               /* The tricky part of the block wise read is to ensure we sent
+               /* The tricky part of the block wise read is to ensure we send
                 * proper newline terminated commands.  Moreover, we would not
                 * like to block due to sending for old files.  */
                /* read the complete file [now trimmed to 64KB]*/
diff --git a/sql/backends/monet5/datacell/emitter.c 
b/sql/backends/monet5/datacell/emitter.c
--- a/sql/backends/monet5/datacell/emitter.c
+++ b/sql/backends/monet5/datacell/emitter.c
@@ -26,7 +26,7 @@
  * DataCell emitter.  It can be used as follows.
  * @example
  * @end example
- * After this call it will sent tuples from basket X_p1
+ * After this call it will send tuples from basket X_p1
  * to the stream Y at the localhost default port.
  *
  * Each emitter is supported by an independent thread
diff --git a/sql/backends/monet5/datacell/receptor.c 
b/sql/backends/monet5/datacell/receptor.c
--- a/sql/backends/monet5/datacell/receptor.c
+++ b/sql/backends/monet5/datacell/receptor.c
@@ -25,7 +25,7 @@
  * This module is a prototype for the implementation of a DataCell receptor.  
It can be used as follows.
  * @example
  * @end example
- * After this call sensors can sent tuples to the
+ * After this call sensors can send tuples to the
  * the stream X at the DataCell connection.
  * They are appended to the event basket with the usec clock tick included.
  *
_______________________________________________
Checkin-list mailing list
[email protected]
http://mail.monetdb.org/mailman/listinfo/checkin-list

Reply via email to
diff --git a/sql/backends/monet5/datacell/actuator.c 
b/sql/backends/monet5/datacell/actuator.c
--- a/sql/backends/monet5/datacell/actuator.c
+++ b/sql/backends/monet5/datacell/actuator.c
@@ -91,7 +91,7 @@ by telephone. Since, the mapping from ev
 specific, the default provided here is to only show the event message.
 
 Users interested in experimentation with real actuators, can hook up the event
-stream with a SCADA system or directly sent the events in a proper format to
+stream with a SCADA system or directly send the events in a proper format to
 the channel where the actuators is listening.
 
 The actuator runs in two modes, active or passive. In the former case, the tool
@@ -172,7 +172,7 @@ static void showStatistics(void)
        mnstr_printf(ACout, "Bandwidth %zu bytes\n", characters * sizeof(char));
 
 
        /* sent a short tuple to stderr for gnuplot datafile*/
        fprintf(stderr, "events %d throughput %6.2f\n", received, 1000000.0 / 
elaps * tuplesIntheBuffer);
        received=0;
@@ -172,7 +172,7 @@ static void showStatistics(void)
 
 
-       /* sent a short tuple to stderr for gnuplot datafile*/
+       /* send a short tuple to stderr for gnuplot datafile*/
        fprintf(stderr, "events %d throughput %6.2f\n", received, 1000000.0 / 
elaps * tuplesIntheBuffer);
        totallatency=0;